@@ -1,4 +1,3 @@
-
 # single response
 "summary.lmp" <- 
 function (object, correlation = FALSE, symbolic.cor = FALSE, ...)
@@ -244,7 +243,7 @@ function (x, digits = max(3, getOption("digits") - 3),
 	if (p > 1) {
 	    cat("\nCorrelation of Coefficients:\n")
 	    if(is.logical(symbolic.cor) && symbolic.cor) {# NULL < 1.7.0 objects
-		print(symnum(correl, abbr.col = NULL))
+		print(symnum(correl, abbr.colnames = NULL))
 	    } else {
                 correl <- format(round(correl, 2), nsmall = 2, digits = digits)
                 correl[!lower.tri(correl)] <- ""
