@@ -14,6 +14,56 @@ void permuteProb(int* Ni, int* nci, double* Y, double* Q, int* nSi, int* dof, do
 void	permuteRand(double** Y,int n);
 
 
+#include <R_ext/Rdynload.h>
+#include <Rinternals.h>
+
+#if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
+#include <stdbool.h>
+#else
+#ifndef __cplusplus
+typedef int bool;
+#define true 1
+#define false 0
+#endif
+#endif
+
+void
+  R_init_mylib(DllInfo *info)
+  {
+    static R_NativePrimitiveArgType permute_t[] = {
+      INTSXP, INTSXP, INTSXP, INTSXP, INTSXP, INTSXP
+    };
+    static R_NativePrimitiveArgType permuteSPR_t[] = {
+      INTSXP, INTSXP, REALSXP, REALSXP, INTSXP, INTSXP, INTSXP, 
+      INTSXP,INTSXP, REALSXP, REALSXP, REALSXP, REALSXP, INTSXP,
+      REALSXP,INTSXP,REALSXP,INTSXP
+    };
+    static R_NativePrimitiveArgType permuteExact_t[] = {
+      INTSXP, INTSXP, REALSXP, REALSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP
+    };
+    static R_NativePrimitiveArgType permuteProb_t[] = {
+      INTSXP, INTSXP, REALSXP, REALSXP, INTSXP, INTSXP, REALSXP, INTSXP, 
+      INTSXP, REALSXP, INTSXP, REALSXP, INTSXP
+    };
+    static const R_CMethodDef cMethods[] = {
+      {"permute", (DL_FUNC) &permute, 6, permute_t},
+      {"permuteExact", (DL_FUNC) &permuteExact, 9, permuteExact_t},
+      {"permuteSPR", (DL_FUNC) &permuteSPR, 18, permuteSPR_t},
+      {"permuteProb", (DL_FUNC) &permuteProb, 13, permuteProb_t},
+      {NULL, NULL, 0, NULL}
+    };
+    
+    R_registerRoutines(info, cMethods, NULL, NULL, NULL);
+    
+    R_useDynamicSymbols(info, FALSE);
+  }
+
+void
+  R_unload_mylib(DllInfo *info)
+  {
+    /* Release resources. */
+  }
+
 #define tol 1e-8
 
 
@@ -473,7 +523,7 @@ void permuteProb(
 	
 	Kt=K-dof[nSe];
 
-	nToDo=nc*(nSe+Kt);
+	nToDo= nc*(nSe+Kt) > 0;
 
 	SS=(double *)S_alloc(nc*nS,sizeof(double));  /* These should be zeroed as allocated */
 	oSS=(double *)S_alloc(nc*nS,sizeof(double));
@@ -776,7 +826,7 @@ void permuteSPR(
 	
 	Kt=K-dof[nSe];
 
-	nToDo=nc*(nSe+Kt);
+	nToDo= nc*(nSe+Kt) != 0;
 
 
 	SS=(double *)S_alloc(nc*nS,sizeof(double));  /* These should be zeroed as allocated */
@@ -857,8 +907,8 @@ void permuteSPR(
 		u1=(int)((double)N*unif_rand()); 
 		u2=(int)((double)N*unif_rand());
 
-		crita=floor(an+(iter)*rn);
-		critr=ceil(bn+(iter)*rn);
+		crita=(int)floor(an+(iter)*rn);
+		critr=(int)ceil(bn+(iter)*rn);
 
 
 		/* Update the SS */
@@ -1019,7 +1069,7 @@ void	permuteRand(
    double temp;
 
    for (i=0;i<n;i++) {
-      j=floor((1+i)*unif_rand());
+      j=(int)floor((1+i)*unif_rand());
       temp=(*Y)[j];
       (*Y)[j]=(*Y)[i];
       (*Y)[i]=temp;
